'''
Django settings for postman project.

Generated by 'django-admin startproject' using Django 2.1.

For more information on this file, see
https://docs.djangoproject.com/en/2.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/2.1/ref/settings/
'''

import os, subprocess
import yaml
from os.path import abspath, basename, dirname, join
from configparser import RawConfigParser
from utils.config import all_config

ALL_CONFIG = all_config

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = dirname(dirname(abspath(__file__)))

# See https://docs.djangoproject.com/en/2.1/howto/deployment/checklist/

# TODO: keep the secret key used in production secret!
SECRET_KEY = 'yn^-h(-ipklep_(plr-@a-5=h!pm0cj)tp+nf%3b&hzeg_fy14'

ALLOWED_HOSTS = ['localhost', '127.0.0.1']

# Load APP configurations
CONFIG_FILE = 'config.ini'
application_config = RawConfigParser()
application_config.read(join(BASE_DIR, CONFIG_FILE))

# Application definition
DJANGO_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',

    # 3rd party
    'rest_framework',
    'django_filters'
]

THIRD_PARTY_APPS = [
    # 'corsheaders',
]

POSTMAN_APPS = [
    'postman',
    'dispatcher',
    'tenant'
]

# See: https://docs.djangoproject.com/en/dev/ref/settings/#installed-apps
INSTALLED_APPS = DJANGO_APPS + THIRD_PARTY_APPS + POSTMAN_APPS

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

REST_FRAMEWORK = {
    'DEFAULT_PARSER_CLASSES': (
        'rest_framework.parsers.JSONParser',
        'rest_framework.renderers.BrowsableAPIRenderer',
    ),
    'DEFAULT_PERMISSION_CLASSES': [
        'rest_framework.permissions.IsAuthenticated',
    ],
    'DEFAULT_AUTHENTICATION_CLASSES': [
        'rest_framework.authentication.SessionAuthentication',
        'utils.schemes.HmacAuthenticationScheme',
    ],
    'DEFAULT_PAGINATION_CLASS': 'rest_framework.pagination.LimitOffsetPagination',
    'PAGE_SIZE': 100
}

# ##### DATABASE CONFIGURATION ############################
DB_HOST = ALL_CONFIG.config.get('postgres').get('pg_host')
DB_NAME = application_config.get('database', 'db_name')
DB_USER = ALL_CONFIG.config.get('postgres').get('pg_user')
DB_PASSWORD = ALL_CONFIG.config.get('postgres').get('pg_password')
# Decrypt DB password
if DB_PASSWORD:
    output = subprocess.check_output(
        ['/opt/cyops-auth/.env/bin/python', '/opt/cyops/configs/scripts/manage_passwords.py', '--decrypt',
         DB_PASSWORD, 'jQp3(7@jod#j38d1']
    ).strip().decode()
    if not output.startswith('Password:'):
        raise Exception('DB Password decrypt failed with Error: %s for Password : %s' % output)
    else:
        DB_PASSWORD = output[len('Password:'):]

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'USER': DB_USER,
        'PASSWORD': DB_PASSWORD,
        'NAME': DB_NAME,
        'HOST': DB_HOST
    }
}

ROOT_URLCONF = 'postman.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
    {
        'NAME': 'jinja2',
        'BACKEND': 'django.template.backends.jinja2.Jinja2',
        'DIRS': [],
        'APP_DIRS': False,
        'OPTIONS': {
            'environment': 'postman.jinja.environment'
        }
    },
]

WSGI_APPLICATION = 'postman.wsgi.application'

# Internationalization
# https://docs.djangoproject.com/en/2.1/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True

# Auth settings
HMAC_TIME_THRESHOLD = 30
HMAC_USER = 'hmac_user'
BASIC_USER = 'basic_user'
ANONYMOUS_USER = 'anon_user'

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.9/howto/static-files/
STATIC_URL = '/static/'
STATIC_ROOT = join(BASE_DIR, 'static/')

TMP_FILE_ROOT = '/tmp/'

# DEBUG
DEBUG = False
if application_config.getboolean('application', 'debug'):
    DEBUG = True

CH_HOST = application_config.get('application', 'app_host')

# Load Appliance Keys
CONFIG_DIR = join(BASE_DIR, 'configs')

APPLIANCE_PUBLIC_KEY = join(CONFIG_DIR, 'APPLIANCE_PUBLIC_KEY')
APPLIANCE_PRIVATE_KEY = join(CONFIG_DIR, 'APPLIANCE_PRIVATE_KEY')
POSTMAN_PUBLIC_KEY = join(CONFIG_DIR, 'postmanpublic.key')
POSTMAN_PRIVATE_KEY = join(CONFIG_DIR, 'postmanprivate.key')
for key in [APPLIANCE_PUBLIC_KEY, APPLIANCE_PRIVATE_KEY, POSTMAN_PUBLIC_KEY, POSTMAN_PRIVATE_KEY]:
    with open(key, 'r') as key_file:
        os.environ.setdefault(key.split(os.sep)[-1], key_file.read().strip())

APPLIANCE_PUBLIC_KEY = os.getenv('APPLIANCE_PUBLIC_KEY', '')
APPLIANCE_PRIVATE_KEY = os.getenv('APPLIANCE_PRIVATE_KEY', '')
POSTMAN_PUBLIC_KEY = os.getenv('postmanpublic.key', '')
POSTMAN_PRIVATE_KEY = os.getenv('postmanprivate.key', '')

CH_MAX_RETRY_COUNT = 10
CH_RETRY_SLEEP = 10

# ##### LOGGING ##############################
APP_LOG_FILE_PATH = application_config.get('logging', 'app_log_file_path')
APP_LOG_FILE_SIZE = eval(application_config.get('logging', 'app_log_file_size'))
APP_LOG_FILE_BACKUP_COUNT = eval(application_config.get('logging', 'app_log_file_backup_count'))

POSTMAN_LOGGER_LEVEL = application_config.get('logging', 'postman_logger_level')
DJANGO_LOGGER_LEVEL = application_config.get('logging', 'django_logger_level')

ROUTER_HEARTBEAT = int(application_config.get('router', 'heartbeat'))
ROUTER_CONNECTION_ATTEMPTS = int(application_config.get('router', 'connection_attempts'))
ROUTER_RETRY_DELAY = int(application_config.get('router', 'retry_delay'))

LOGGING = {
    'version': 1,
    'disable_existing_loggers': True,
    'formatters': {
        'verbose': {
            'format': '%(asctime)s %(thread)d %(threadName)s %(levelname)s %(name)s %(module)s %(funcName)s(): %(message)s'
        }
    },
    'handlers': {
        'app_logger': {
            'class': 'logging.handlers.RotatingFileHandler',
            'filename': APP_LOG_FILE_PATH,
            'maxBytes': APP_LOG_FILE_SIZE,
            'backupCount': APP_LOG_FILE_BACKUP_COUNT,
            'formatter': 'verbose'
        }
    },
    'loggers': {
        'dispatcher': {
            'handlers': ['app_logger'],
            'level': POSTMAN_LOGGER_LEVEL,
            'propagate': False
        },
        'tenant': {
            'handlers': ['app_logger'],
            'level': POSTMAN_LOGGER_LEVEL,
            'propagate': False
        },
        'postman': {
            'handlers': ['app_logger'],
            'level': POSTMAN_LOGGER_LEVEL,
            'propagate': False
        },
        'utils': {
            'handlers': ['app_logger'],
            'level': POSTMAN_LOGGER_LEVEL,
            'propagate': False
        },
        'pika': {
            'handlers': ['app_logger'],
            'level': POSTMAN_LOGGER_LEVEL,
            'propagate': False
        },
        'django.request': {
            'handlers': ['app_logger'],
            'level': DJANGO_LOGGER_LEVEL,
            'propagate': False
        }
    }
}
SELF_ID = None
REMOTE_USER_ID = '/api/3/people/441c0092-8db1-4299-ba1a-6d704465465a'
TENANTS = dict()
ROUTERS = dict()
IS_MASTER = None
LOG_PAGINATION = 100
TENANT_CONFIG_STATUS = {'-1':
    {
        'iri': '/api/3/picklists/e5c81dc9-1e7f-4f3d-9460-760044aa8d5b',
        'itemValue': 'Configuration Failed'
    },
    '0': {
        'iri': '/api/3/picklists/29395624-0300-46a5-90b3-a6af4c5154d9',
        'itemValue': 'Not Configured',

    },
    '1': {
        'iri': '/api/3/picklists/0dff7239-38a4-4dc8-9fe6-97932d2bd35f',
        'itemValue': 'Configuration In Progress',

    },
    '2': {
        'iri': '/api/3/picklists/e89a4393-98b4-4d62-8083-a652b6a4a2d7',
        'itemValue': 'Configured',
    },
    '3': {
        'iri': '/api/3/picklists/23987b58-da1b-4905-a97c-5348829b5339',
        'itemValue': 'Connection Verified',

    },
    '4': {
        'iri': '/api/3/picklists/429a76e8-c62b-4fe6-b61c-c3805f22c2b3',
        'itemValue': 'Connection Verification Failed',

    }}

